# Contributing

For contributions, create a separated branch with your changes and open
a pull-request targeting the development branch to which your changes
will be merged.

Development branches are named after the target version of the project.

Example:

- master
- v0.1.0
- v0.1.1

In the example above there are two active development branches: `v0.1.0` and `v0.1.1`.

This project uses [semantic versioning 2.0](https://semver.org/).
